@@ -14,8 +14,9 @@
 # along with ngs_plumbing.  If not, see <http://www.gnu.org/licenses/>.
 
 # Copyright 2012 Laurent Gautier
-
 """ Various utilities to report results / make reports with results """
+from collections import OrderedDict
+import json
 
 def fastqual_tocsv_iter(fq):
     """ fq: result returned by xsq.fastqual() """
@@ -26,3 +27,13 @@ def fastqual_tocsv_iter(fq):
         res = tuple( [basepos + 1, ] + [getattr(val, x) for x in fq[0]._fields])
         yield res
 
+def fastqual_tojson(fq):
+    """ fq: result returned by xsq.fastqual() """
+    res = list()
+    for basepos, val in enumerate(fq):
+        od = OrderedDict()
+        od['basepos'] = basepos +1
+        for h,v in zip(fq[0]._fields, val):
+            od[h] = v
+        res.append(od)
+    return json.dumps(res)
