@@ -434,6 +434,7 @@ def make_fastq(lib, fragment, buf, f, flowcell, numbase = None,
                                                                     n_count * 100.0 / (read_count * len(dna))))
     out.flush()
 
+
 def make_csfasta(lib, fragment, buf_cs, buf_qual, f, flowcell, 
                  numbase = None, progress_mark = 50000, out=sys.stdout):
     read_count = long(0)
@@ -467,11 +468,49 @@ def make_csfasta(lib, fragment, buf_cs, buf_qual, f, flowcell,
     out.write("%i reads (%.3fGb).\n" %(read_count, read_count*numbase / 1E9))
     out.flush()
 
+def make_csfastq(lib, fragment, buf, f, flowcell, 
+                 numbase = None, progress_mark = 50000, out=sys.stdout):
+    read_count = long(0)
+    inc = long(1)
+
+    for tile_i, (tile_n, a) in enumerate(iter_valuearrays(lib, fragment, 
+                                                          what='ColorCallQV')):
+        if numbase is None:
+            numbase = a.shape[1]
+        seq_id = seqid_template_csfasta(flowcell, fragment)
+        xyloc = lib[tile_n]['Fragments'][u'yxLocation'][:]
+        read_count += xyloc.shape[0]
+        prefix = FRAGMENT_START[fragment]
+        for row_i in _progress_bar_iter(xrange(a.shape[0]), 
+                                        suffix = ' tile: %i'%(tile_i+1)): 
+            seq, qual = colourqual_frombuffer(a[row_i])
+            seq = bytearray_addint(seq, 48)
+            
+            x,y = xyloc[row_i]
+            buf.write(seq_id %(x,y))
+            buf.write('\n')
+            buf_cs.write(prefix)
+            buf_cs.write(seq)
+            buf.write('\n+\n')
+            buf.write(' '.join( str(q) for q in qual))
+            buf.write('\n')
+
+    if os.isatty(out.fileno()):
+        out.write('\n')
+    out.write("%i reads (%.3fGb).\n" %(read_count, read_count*numbase / 1E9))
+    out.flush()
+
 
 def automagic_fastq(filename, path_out = '.', fragment = None, 
-                    buf_size = long(2E6), extension = 'fq', out = sys.stdout):
+                    buf_size = long(2E6), extension = 'fq', out = sys.stdout,
+                    cs = False):
     """ Extract sequence-space data into a FASTAQ file """
 
+    if cs:
+        maker = make_csfastq
+    else:
+        maker = make_fastq
+
     f = XSQFile(filename, 'r')
     p = re.compile('.+_([0-9]+)\.xsq')
 
@@ -492,12 +531,13 @@ def automagic_fastq(filename, path_out = '.', fragment = None,
             out_f = io.FileIO(os.path.join(path_out, "%s_%s.%s" %(lib_name, frg, extension)), "w")
             buf = io.BufferedWriter(out_f, buf_size)
 
-            make_fastq(lib, frg, buf, f, flowcell)                
+            maker(lib, frg, buf, f, flowcell)                
             buf.flush()
             out_f.close()    
     f.close()
 
-def automagic_csfasta(filename, path_out = '.', fragment = None, buf_size = long(2E6), out = sys.stdout):
+def automagic_csfasta(filename, path_out = '.', fragment = None, 
+                      buf_size = long(2E6), out = sys.stdout):
     """ Extract sequence-space data into a FASTAQ file """
 
     assert((fragment is None) or (fragment in FRAGMENT_NAMES))
