@@ -113,11 +113,17 @@ def main():
                     xsq.automagic_fastq(f, path_out = dest_dir, 
                                         fragment = None, 
                                         buf_size = long(2E6), 
-                                        out = sys.stdout)
+                                        out = sys.stdout,
+                                        cs = False)
                 except KeyError, ke:
                     print('\nError: No base calls for file "%s".' %f)
             else:
-                print('Error: Naive conversion not yet implemented (and you should be using colour space anyway, don\'t you think ?). Try requiring ECC calls.')
+                    xsq.automagic_fastq(f, path_out = dest_dir, 
+                                        fragment = None, 
+                                        buf_size = long(2E6), 
+                                        out = sys.stdout,
+                                        extension = 'csfq',
+                                        cs = True)
 
     if (not options.to_csfasta) and (not options.to_fastq):
         print('Error: Neither CSFASTA+QUAL nor FASTQ was wanted, so nothing was done. Goodbye.')
